#!/usr/bin/env python
from __future__ import print_function
import sys
import numpy as np
#np.set_printoptions(threshold=sys.maxsize)
import mandelbrot_ext as mandel
import matplotlib
matplotlib.use('Agg')
import matplotlib.pyplot as plt
import matplotlib.cm as cm
import time



# this fills in a 1D array size of im_width*im_height then reshapes it into
# a 2D array. Can you make this faster?
def mandelbrot_loop(im_width, im_height, xwidth, yheight, xmin, ymin, nitmax):
    zabsmax = 2.0
    maxval=0;
    mm = np.zeros((im_width * im_height))
    for i in range(im_width * im_height):
        ix = int(i/im_width)
        iy = i - ix * im_width
        nit = 0
        c = complex(xmin + float(ix)*xwidth/im_width ,
                    ymin + float(iy)*yheight/im_height)
        z = 0.0j;
        mm[i] = mandel.calcz(z,c,zabsmax)
        if mm[i] == 1.0:
            mm[i] = 0.0;
        else:
            mm[i] *= 1000.0;
    return mm.reshape(im_width,im_height)






if __name__ == '__main__':
    #if len(sys.argv)>4:
        # fill in the center coordinates X and Y
        # and the range R
    #else:
    X = -0.7453
    Y = 0.1127
    R = 0.00065
    print("Mandelbrot set fractal generator for coordinates {}/{}\n".format(X, Y))
    im_width = 1000
    im_height = 1000
    ymin,ymax = X-R, X+R
    xmin, xmax = Y-R, Y+R
    xwidth = xmax-xmin
    yheight = ymax - ymin
    nitmax = 10000
    zabsmax = 2.0
    tic = time.time()
    mm = mandelbrot_loop(im_width, im_height, yheight, xwidth, ymin, xmin, nitmax)
    toc = time.time()
    print("Elapsed time for calculations:",toc-tic)
    print("Plot the Mandelbrot set into the file mandelbrotfig.pdf")
    fig, ax = plt.subplots()
    ax.imshow(mm, interpolation='nearest', cmap=cm.jet)
    plt.savefig('mandelbrotfig.pdf')
